==> cdk-k3s-cluster-0.0.48.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### 0.0.48 (2020-11-28)

### 0.0.47 (2020-10-19)

### 0.0.46 (2020-10-15)

### 0.0.45 (2020-10-15)

### 0.0.44 (2020-10-12)

### 0.0.43 (2020-10-07)

### 0.0.42 (2020-10-07)

### 0.0.41 (2020-10-07)

### 0.0.40 (2020-10-07)

### 0.0.39 (2020-10-06)

### 0.0.38 (2020-10-06)

### 0.0.37 (2020-10-05)

### 0.0.36 (2020-10-03)

### 0.0.35 (2020-10-01)

### 0.0.34 (2020-10-01)

### 0.0.33 (2020-09-30)

### 0.0.32 (2020-09-30)

### 0.0.31 (2020-09-30)

### 0.0.30 (2020-09-30)

### 0.0.29 (2020-09-29)

### 0.0.28 (2020-09-25)

### 0.0.27 (2020-09-25)

### 0.0.26 (2020-09-22)

### 0.0.25 (2020-09-22)

### 0.0.24 (2020-09-21)

### 0.0.23 (2020-09-21)

### 0.0.22 (2020-09-17)


### Features

* **core:** create ASG with launch template ([#23](https://github.com/aws-samples/aws-cdk-for-k3scluster/issues/23)) ([994dcda](https://github.com/aws-samples/aws-cdk-for-k3scluster/commit/994dcda5d8f9ea98fc6bffc14f0162eb0b582b83))

### 0.0.21 (2020-09-17)

### 0.0.20 (2020-09-17)

### 0.0.19 (2020-09-17)

### 0.0.18 (2020-09-17)

### 0.0.17 (2020-09-16)

### 0.0.16 (2020-09-16)

### 0.0.15 (2020-09-16)

### 0.0.14 (2020-09-16)


### Features

* **core:** add t4g instance types in the PriceMap ([#19](https://github.com/aws-samples/aws-cdk-for-k3scluster/issues/19)) ([547a393](https://github.com/aws-samples/aws-cdk-for-k3scluster/commit/547a3935e53aeb73a7820e371d84f39b02063e39))

### 0.0.13 (2020-09-15)

### 0.0.12 (2020-09-15)

### 0.0.11 (2020-09-15)

### 0.0.10 (2020-09-14)

### 0.0.9 (2020-09-14)

### 0.0.8 (2020-09-14)

### 0.0.7 (2020-09-12)

### [0.0.6](https://github.com/aws-samples/aws-cdk-for-k3scluster/compare/v0.0.5...v0.0.6) (2020-09-11)

### 0.0.5 (2020-09-11)

### 0.0.4 (2020-09-11)

### 0.0.3 (2020-09-11)

### 0.0.2 (2020-09-10)

### 0.0.1 (2020-09-10)

==> cdk-k3s-cluster-0.0.57.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.0.51](https://github.com/aws-samples/aws-cdk-for-k3scluster/compare/v0.0.50...v0.0.51) (2021-03-16)

### [0.0.50](https://github.com/aws-samples/aws-cdk-for-k3scluster/compare/v0.0.47...v0.0.50) (2021-03-16)


### Bug Fixes

* invalid iam profile ([4324820](https://github.com/aws-samples/aws-cdk-for-k3scluster/commit/43248202fdd81b45d1263ec72e2e8907e738601b))
* projen now requires defaultReleaseBranch ([4566cdc](https://github.com/aws-samples/aws-cdk-for-k3scluster/commit/4566cdcd92dfb5ffd61f171880f65004357e00d1))
* remove-custom-resource ([3d0c765](https://github.com/aws-samples/aws-cdk-for-k3scluster/commit/3d0c76595287e85e9cfca66084af3b08daddb3be))

### 0.0.48 (2020-11-28)

### 0.0.47 (2020-10-19)

### 0.0.46 (2020-10-15)

### 0.0.45 (2020-10-15)

### 0.0.44 (2020-10-12)

### 0.0.43 (2020-10-07)

### 0.0.42 (2020-10-07)

### 0.0.41 (2020-10-07)

### 0.0.40 (2020-10-07)

### 0.0.39 (2020-10-06)

### 0.0.38 (2020-10-06)

### 0.0.37 (2020-10-05)

### 0.0.36 (2020-10-03)

### 0.0.35 (2020-10-01)

### 0.0.34 (2020-10-01)

### 0.0.33 (2020-09-30)

### 0.0.32 (2020-09-30)

### 0.0.31 (2020-09-30)

### 0.0.30 (2020-09-30)

### 0.0.29 (2020-09-29)

### 0.0.28 (2020-09-25)

### 0.0.27 (2020-09-25)

### 0.0.26 (2020-09-22)

### 0.0.25 (2020-09-22)

### 0.0.24 (2020-09-21)

### 0.0.23 (2020-09-21)

### 0.0.22 (2020-09-17)


### Features

* **core:** create ASG with launch template ([#23](https://github.com/aws-samples/aws-cdk-for-k3scluster/issues/23)) ([994dcda](https://github.com/aws-samples/aws-cdk-for-k3scluster/commit/994dcda5d8f9ea98fc6bffc14f0162eb0b582b83))

### 0.0.21 (2020-09-17)

### 0.0.20 (2020-09-17)

### 0.0.19 (2020-09-17)

### 0.0.18 (2020-09-17)

### 0.0.17 (2020-09-16)

### 0.0.16 (2020-09-16)

### 0.0.15 (2020-09-16)

### 0.0.14 (2020-09-16)


### Features

* **core:** add t4g instance types in the PriceMap ([#19](https://github.com/aws-samples/aws-cdk-for-k3scluster/issues/19)) ([547a393](https://github.com/aws-samples/aws-cdk-for-k3scluster/commit/547a3935e53aeb73a7820e371d84f39b02063e39))

### 0.0.13 (2020-09-15)

### 0.0.12 (2020-09-15)

### 0.0.11 (2020-09-15)

### 0.0.10 (2020-09-14)

### 0.0.9 (2020-09-14)

### 0.0.8 (2020-09-14)

### 0.0.7 (2020-09-12)

### [0.0.6](https://github.com/aws-samples/aws-cdk-for-k3scluster/compare/v0.0.5...v0.0.6) (2020-09-11)

### 0.0.5 (2020-09-11)

### 0.0.4 (2020-09-11)

### 0.0.3 (2020-09-11)

### 0.0.2 (2020-09-10)

### 0.0.1 (2020-09-10)
